==> sptk-2.3.28.tbz2: sptk-2.3.28/src/CException.cpp <==
/***************************************************************************
                          SIMPLY POWERFUL TOOLKIT (SPTK)
                          cexception.cpp  -  description
                             -------------------
    begin                : Thu Apr 27 2000
    copyright            : (C) 2000-2003 by Alexey S.Parshin
    email                : alexeyp@gmail.com
 ***************************************************************************/

/***************************************************************************
   This library is free software; you can redistribute it and/or modify it 
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at 
   your option) any later version.

   This library is distributed in the hope that it will be useful, but 
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Library
   General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.

   Please report all bugs and problems to "alexeyp@gmail.com"
 ***************************************************************************/

#include <sptk/CException.h>

CException::CException(const CString text,const CString file,int line,CString description) {
	m_file = file;
	m_text = text;
	m_line = line;
	m_description = description;
}

CString CException::text(bool shortVersion) const {
	if (!shortVersion && m_line) {
		CString fullMessage("Error in file "+m_file+"["+CString(m_line)+"]: " + m_text);
		if (m_description[0])
			fullMessage += "\n" + m_description;
		return fullMessage;
	}
	else  return m_text;
}

==> sptk-3.0.6.tbz2: sptk-3.0.6/src/CException.cpp <==
/***************************************************************************
                          SIMPLY POWERFUL TOOLKIT (SPTK)
                          cexception.cpp  -  description
                             -------------------
    begin                : Thu Apr 27 2000
    copyright            : (C) 2000-2005 by Alexey S.Parshin
    email                : alexeyp@gmail.com
 ***************************************************************************/

/***************************************************************************
   This library is free software; you can redistribute it and/or modify it 
   under the terms of the GNU Library General Public License as published by
   the Free Software Foundation; either version 2 of the License, or (at 
   your option) any later version.

   This library is distributed in the hope that it will be useful, but 
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Library
   General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.

   Please report all bugs and problems to "alexeyp@gmail.com"
 ***************************************************************************/

#include <sptk3/CException.h>
#include <sptk3/CStrings.h>

using namespace std;

CException::CException(string text,string file,int line,string description) {
   m_file = file;
   m_text = text;
   m_line = line;
   m_description = description;
   m_fullMessage = m_text;

   if (m_line && !m_file.empty()) 
      m_fullMessage = "Error in file "+m_file+"["+int2string(m_line)+"]: " + m_text;

   if (!m_description.empty())
      m_fullMessage += "\n" + m_description;
}
